@@ -1,4 +1,6 @@
+from typing import Any, Optional, Union
 import PCGCPP
+import numpy.typing as npt
 
 class PCG32:
     """Wrapper around the pcg32 class.
@@ -9,7 +11,7 @@ class PCG32:
     >>> rng.randint()
     2336806640
     """
-    def __init__(self, stream = None, state = None):
+    def __init__(self, stream: Optional[int] = None, state: Optional[int] = None):
         if stream and state:
             self.capsule = PCGCPP.construct(stream, state)
         elif stream:
@@ -17,13 +19,13 @@ class PCG32:
         else:
             self.capsule = PCGCPP.construct()
     
-    def randint(self, size = 1, bound = 0):
+    def randint(self, size: int = 1, bound: int = 0) -> Union[npt.NDArray[Any], int]:
         """Draw a random integer, with an optional upper bound.
         
         >>> rng = PCG32(42, 54)
-        >>> rng.randint(2)
+        >>> rng.randint(2).tolist()
         [1070908346, 3346215311]
-        >>> rng.randint(2, bound=100)
+        >>> rng.randint(2, bound=100).tolist()
         [67, 65]
         """
         result = PCGCPP.randint(self.capsule, size, bound)
@@ -33,11 +35,11 @@ class PCG32:
         
         return result
     
-    def rand(self, size = 1):
+    def rand(self, size: int = 1) -> Union[npt.NDArray[Any], float]:
         """Draw a uniform random number in the interval [0,1).
 
-        >>> rng = PCG32(42 ,54)
-        >>> rng.rand(2)
+        >>> rng = PCG32(42, 54)
+        >>> rng.rand(2).tolist()
         [0.24934027949348092, 0.7791014646645635]
         """
         result = PCGCPP.rand(self.capsule, size)
@@ -47,11 +49,11 @@ class PCG32:
         
         return result
     
-    def randn(self, size = 1):
+    def randn(self, size: int = 1) -> Union[npt.NDArray[Any], float]:
         """Draw a random number following a standard normal PDF.
 
-        >>> rng = PCG32(42 ,54)
-        >>> rng.randn(2)
+        >>> rng = PCG32(42, 54)
+        >>> rng.randn(2).tolist()
         [-0.6765672580042227, 0.7691621258667373]
         """
         result = PCGCPP.randn(self.capsule, size)
@@ -63,4 +65,4 @@ class PCG32:
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod()
+    doctest.testmod(verbose=True)
